/*
 * ioGame
 * Copyright (C) 2021 - 2023  渔民小镇 （262610965@qq.com、luoyizhu@gmail.com） . All Rights Reserved.
 * # iohao.com . 渔民小镇
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.iohao.mmo.person.entity;

import lombok.*;
import lombok.experimental.FieldDefaults;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.Objects;

/**
 * 基础属性
 * <pre>
 *     人物的基本属性、英雄的基本属性
 * </pre>
 *
 * @author 渔民小镇
 * @date 2023-07-24
 */
@Data
@Document
@FieldDefaults(level = AccessLevel.PRIVATE)
public class BasicsProperty {
    @Id
    String id;
    /** 生命值 */
    int hp;
    /** 魔法值 */
    int mp;
    /** 物理攻击 */
    int physicsAttack;
    /** 物理防御 */
    int physicsDefense;
    /** 魔法攻击 */
    int magicAttack;
    /** 魔法防御 */
    int magicDefense;
    /** 治疗强度 */
    int treatAttack;
    /** 封印强度 */
    int sealAttack;
    /** 封印防御（抵抗封印） */
    int sealDefense;
    /** 速度 */
    int speed;
    /** 怒气 */
    int anger;

    public BasicsProperty plus(BasicsProperty basicsProperty) {

        if (Objects.isNull(basicsProperty)) {
            basicsProperty = new BasicsProperty();
        }

        BasicsProperty the = new BasicsProperty();
        the.hp = this.hp + basicsProperty.hp;
        the.mp = this.mp + basicsProperty.mp;
        the.physicsAttack = this.physicsAttack + basicsProperty.physicsAttack;
        the.physicsDefense = this.physicsDefense + basicsProperty.physicsDefense;
        the.magicAttack = this.magicAttack + basicsProperty.magicAttack;
        the.magicDefense = this.magicDefense + basicsProperty.magicDefense;
        the.treatAttack = this.treatAttack + basicsProperty.treatAttack;
        the.sealAttack = this.sealAttack + basicsProperty.sealAttack;
        the.sealDefense = this.sealDefense + basicsProperty.sealDefense;
        the.speed = this.speed + basicsProperty.speed;
        the.anger = this.anger + basicsProperty.anger;

        return the;
    }
}
